pub struct Page<T> {
pub items: Vec<T>,
pub total: u64,
pub page: u64,
pub per_page: u64,
}Expand description
A page of results returned from a repository query.
Fields
items: Vec<T>The items in this page.
total: u64The total number of items across all pages.
page: u64The 1-based page number of this page.
per_page: u64The number of items per page.
Implementations
Sourceimpl<T> Page<T>
impl<T> Page<T>
Sourcepub fn total_pages(&self) -> u64
pub fn total_pages(&self) -> u64
Returns the total number of pages.
Sourcepub fn has_next_page(&self) -> bool
pub fn has_next_page(&self) -> bool
Returns true if there is a page after this one.